@@ -2,6 +2,9 @@ describe.oprobit<-function(){
 
 category <- "ordinal"
 description  <- "Ordinal Probit Regression for Ordered Categorical Dependent Variables"
+authors <- c()
+year <- 2007
+
 package <-list(	name 	="MASS",
 		version	="0.1"
 		)
@@ -14,6 +17,6 @@ parameters$mu<-list(equations=c(1,1),
 			varInSpecialFunction=c(1,1)
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 
 }
