@@ -1,6 +1,8 @@
 describe.poisson.mixed <- function(){
   category <- "count"
   description  <- "Mixed effects poisson model"
+  authors <- c("Delia Bailey", "Ferdinand Alimadhi")
+  year <- 2007
   parameters <- list(mu="mu", delta="delta", sigma2="sigma2")
 
   parameters$mu <- list(equations=c(1,1),
@@ -23,7 +25,7 @@ describe.poisson.mixed <- function(){
   package <- list(name="lme4", version="0.99875-9")
   
 
-  list(category=category, package=package, description = description, parameters=parameters)
+  list(category = category, authors = authors, year = year, package=package, description = description, parameters=parameters)
 }
 
   
